@@ -1,7 +1,22 @@
 package File::UStore;
 
+use 5.006;
 use strict;
 use warnings;
+
+=head1 NAME
+
+File::UStore - Perl extension to store files  on a filesystem using a non-hash UUID(Universally Unique Identifier) based randomised storage with depth of storage options.
+
+=head1 VERSION
+
+Version 0.04
+
+=cut
+
+our $VERSION = '0.04';
+
+
 use UUID;
 use File::Copy;
 use File::Path;
@@ -24,7 +39,59 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( );
 
-our $VERSION = '0.03';
+=head1 SYNOPSIS
+
+  use File::UStore;
+  my $store = new File::UStore( path => "/home/shantanu/.teststore", 
+                              prefix => "prefix_",
+                              depth  => 5
+                            );
+  
+  open( my $FH, "foo.pl" ) or die "Unable to open file ";
+  # Add a file in the store
+  my $id = $store->add(*$FH);
+
+  # Get file handle from id. this might not work if you have too wierd a storage scheme.
+  my $handle = $store->get($id);
+  print <$handle>;
+
+  # Return the filesystem location of an id
+  my $location = $store->getPath($id);
+
+  # Remove a file by its id from the store
+  $store->remove("7d4d873e-4bf4-41a5-8696-fd6232f7bdda");
+
+=head1 DESCRIPTION
+
+File::UStore is a perl library based on File::HStore to store files on a filesystem using a UUID based randomised storage with folder depth control over storage.
+
+File::UStore is a library that allows users to abstract file storage using a UUID based pointer instead of File Hashes to store the file. This is a critical feature for code which requires even duplicate files to get a unique identifier each time they added to a store. A Hash Storage on the other hand will not allow a file to be duplicated if it is stored multiple time in the store. This can cause issues in cases where a files may be deleted regularly as there would be no way of knowing if a second process is still using the file which the first process might be about to delete.
+
+The  current version  uses UUID Module to generate universally unique identifiers everytime a file is to be stored.
+
+The Module also provides a option to choose the folder depth at which a file is stored. This can be changed from the default value of 3. Increasing depth is advisable 
+if the store might contain a large number of files in your use case. This will help to avoid having a too large number of files in any single folder.
+
+=cut
+
+=head1 SUBROUTINES/METHODS
+
+The object  oriented interface to C<File::UStore> is  described in this
+section.  
+
+The following methods are provided:
+
+=head2 new
+
+=item $store = File::UStore->new( path => "/home/shantanu/.teststore", prefix => "prefix_", depth  => 5 );
+
+This constructor  returns a new C<File::UStore>  object encapsulating a
+specific store. The path specifies  where the UStore is located on the
+filesystem.  If the  path  is  not specified,  the  path ~/.ustore  is
+used. The $prefix is an extension to specify the prefix appended before 
+unique file name.
+
+=cut
 
 sub new {
 
@@ -66,6 +133,17 @@ sub new {
     return $self;
 }
 
+=head2 add
+
+=item $store->add($filename)
+
+The $filename is the file to be added in the  store. The return value
+is the id ($id) of the $filename stored. From this point on the user 
+will only be able to refer to this file using the id.
+Return undef on error. 
+
+=cut
+
 sub add {
 
     my ( $self, $file) = @_;
@@ -95,6 +173,17 @@ sub add {
     return $uuidString;
 }
 
+=head2 remove
+
+=item $store->remove($id)
+
+The $id is the file to be removed from the store. 
+
+Return false on success and undef on error.
+
+
+=cut
+
 sub remove {
 
     my ( $self, $id ) = @_;
@@ -124,6 +213,16 @@ sub remove {
 
 }
 
+=head2 get
+
+=item $store->get($id)
+
+Return the file handle of the file from its id.
+
+Return undef on error.
+
+=cut
+
 sub get {
 
     my ( $self, $id ) = @_;
@@ -148,7 +247,17 @@ sub get {
     }
 }
 
-sub getpath {
+=head2 getPath
+
+=item $store->getPath($id)
+
+Return the filesystem location of the file from its id.
+
+Return undef on error.
+
+=cut
+
+sub getPath {
 
     my ( $self, $id ) = @_;
 
@@ -171,6 +280,7 @@ sub getpath {
     }
 }
 
+# local Function
 sub _printPath {
     my ($self) = @_;
 
@@ -181,98 +291,6 @@ sub _printPath {
 1;
 __END__
 
-=head1 NAME
-
-File::UStore - Perl extension to store files  on a filesystem using a non-hash UUID(Universally Unique Identifier) based randomised storage with depth of storage options.
-
-=head1 SYNOPSIS
-
-  use File::UStore;
-  my $store = new File::UStore( path => "/home/shantanu/.teststore", 
-                              prefix => "prefix_",
-                              depth  => 5
-                            );
-  
-  open( my $FH, "foo.pl" ) or die "Unable to open file ";
-  # Add a file in the store
-  my $id = $store->add(*$FH);
-
-  # Get file handle from id. this might not work if you have too wierd a storage scheme.
-  my $handle = $store->get($id);
-  print <$handle>;
-
-  # Return the filesystem location of an id
-  my $location = $store->getpath($id);
-
-  # Remove a file by its id from the store
-  $store->remove("7d4d873e-4bf4-41a5-8696-fd6232f7bdda");
-
-=head1 DESCRIPTION
-
-File::UStore is a perl library based on File::HStore module by Alexandre Dulaunoy 
-to store files  on a filesystem using a UUID based randomised storage
-with folder depth control over storage.
-
-File::UStore is a library that allows users to abstract file storage using
-a UUID based pointer instead of File Hashes to store the file.
-This is a critical feature for code which requires even duplicate files to get a unique 
-identifier each time they added to a store. A Hash Storage on the
-other hand will not allow a file to be duplicated if it is stored multiple
-time in the store. This can cause issues in cases where a files may be 
-deleted regularly as there would be no way of knowing if a second process
-is still using the file which the first process might be about to delete.
-
-The  current version  uses UUID Module to generate universally unique identifiers
-everytime a file is to be stored.
-
-The Module also provides a option to choose the folder depth at which a file is stored.
-This can be changed from the default value of 3. Increasing depth is advisable 
-if the store might contain a large number of files in your use case. This will help
-to avoid having a too large number of files in any single folder.
-
-=head1 METHODS
-
-The object  oriented interface to C<File::UStore> is  described in this
-section.  
-
-The following methods are provided:
-
-=over 4
-
-=item $store = File::UStore->new( path => "/home/shantanu/.teststore", prefix => "prefix_", depth  => 5 );
-
-This constructor  returns a new C<File::UStore>  object encapsulating a
-specific store. The path specifies  where the UStore is located on the
-filesystem.  If the  path  is  not specified,  the  path ~/.ustore  is
-used. The $prefix is an extension to specify the prefix appended before 
-unique file name.
-
-=item $store->add($filename)
-
-The $filename is  the file to be added in the  store. The return value
-is the id ($id) of the $filename stored. From this point on the user 
-will only be able to refer to this file using the id.
-Return undef on error. 
-
-=item $store->get($id)
-
-Return the file handle of the file from its id.
-
-Return undef on error.
-
-=item $store->getpath($id)
-
-Return the filesystem location of the file from its id.
-
-Return undef on error.
-
-=item $store->remove($id)
-
-The $id is the file to be removed from the store. 
-
-Return false on success and undef on error.
-
-=back
 
 =head1 SEE ALSO
 
@@ -280,13 +298,9 @@ An Analysis of Compare-by-hash - for reasons why a UUID based storage may
 be preferred over hash based solution in certain cases.
 http://www.usenix.org/events/hotos03/tech/full_papers/henson/henson.pdf
 
-=head1 AUTHOR
-
-Shantanu Bhadoria, E<lt>shantanu (dot comes here) bhadoria at gmail dot comE<gt>
-
 =head1 USE CASE FOR THIS MODULE IN LIEU OF A HASH BASED STORAGE
 
-File::HStore by Alexandre Dulaunoy, is a similar module that
+File::HStore is a similar module that
 provides File Hash based storage. However due to the nature of File
 Hashing, File::HStore doesn't allow duplicates. If the same file is
 stored a second time using File::HStore it transparently returns the
@@ -312,17 +326,62 @@ performance for the users application. Depth of storage allows users
 to make the balance between average "number of files in a folder"
 and folder depth.
 
+=head1 AUTHOR
+
+Shantanu Bhadoria, C<< <shantanu (dot comes here) bhadoria at gmail dot com> >> L<http://www.shantanubhadoria.com>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-file-ustore at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-UStore>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc File::UStore
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-UStore>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/File-UStore>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/File-UStore>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/File-UStore/>
+
+=back
+
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to Alexandre Dulaunoy for the excellent File::HStore module which along with my own special need provided the idea behind this module.
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011 by Shantanu Bhadoria  <shantanu (dot comes here) bhadoria at gmail dot com> http://www.shantanubhadoria.com
+Copyright (C) 2011 Shantanu Bhadoria  
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.5 or,
-at your option, any later version of Perl 5 you may have available.
+C<< <shantanu (dot comes here) bhadoria at gmail dot com> >> L<http://www.shantanubhadoria.com>
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
 
 =head1 Dependencies 
 
-
 UUID
 
 File::Copy
